@@ -88,7 +88,7 @@ impl BinColumn {
         BinColumnIt {
             pos: 0,
             num_rows,
-            col: &self,
+            col: self,
         }
     }
 
@@ -319,7 +319,7 @@ impl<'a> BinColumnWriter<'a> {
     ///     Some(&[7,8,9,10,11,12]),
     /// ];
     ///
-    /// let mut buffer = ColumnarRowSet::new(input.len() as u32, iter::once(desc));
+    /// let mut buffer = ColumnarRowSet::new(input.len(), iter::once(desc));
     ///
     /// buffer.set_num_rows(input.len());
     /// if let AnyColumnViewMut::Binary(mut writer) = buffer.column_mut(0) {
