@@ -79,6 +79,13 @@ pub struct NullableSlice<'a, T> {
     values: &'a [T],
 }
 
+impl<'a, T> NullableSlice<'a, T> {
+    /// Number of entries in this slice of the buffer
+    pub fn len(&self) -> usize {
+        self.values.len()
+    }
+}
+
 impl<'a, T> Iterator for NullableSlice<'a, T> {
     type Item = Option<&'a T>;
 
@@ -174,6 +181,13 @@ pub struct NullableSliceMut<'a, T> {
     values: &'a mut [T],
 }
 
+impl<'a, T> NullableSliceMut<'a, T> {
+    /// Number of entries in this slice of the buffer
+    pub fn len(&self) -> usize {
+        self.values.len()
+    }
+}
+
 impl<'a, T> NullableSliceMut<'a, T> {
     /// Writes the elements returned by the iterator into the buffer, starting at the beginning.
     /// Writes elements until the iterator returns `None` or the buffer can not hold more elements.
