@@ -131,13 +131,14 @@ fn describe_columns() {
             "TIME",
             "text",
             "Image",
+            "DOUBLE PRECISION",
         ],
     )
     .unwrap();
-    let sql = "SELECT a,b,c,d,e,f,g,h,i,j FROM DescribeColumns ORDER BY Id;";
+    let sql = "SELECT a,b,c,d,e,f,g,h,i,j,k FROM DescribeColumns ORDER BY Id;";
     let cursor = conn.execute(sql, ()).unwrap().unwrap();
 
-    assert_eq!(cursor.num_result_cols().unwrap(), 10);
+    assert_eq!(cursor.num_result_cols().unwrap(), 11);
     let mut actual = ColumnDescription::default();
 
     let desc = |name, data_type, nullability| ColumnDescription {
@@ -212,6 +213,12 @@ fn describe_columns() {
     cursor.describe_col(10, &mut actual).unwrap();
     assert_eq!(expected, actual);
     assert_eq!(kind, cursor.col_data_type(10).unwrap());
+
+    let kind = DataType::Float { precision: 53 };
+    let expected = desc("k", kind, Nullability::Nullable);
+    cursor.describe_col(11, &mut actual).unwrap();
+    assert_eq!(expected, actual);
+    assert_eq!(kind, cursor.col_data_type(11).unwrap());
 }
 
 #[test]
@@ -2123,14 +2130,15 @@ fn use_truncated_output_as_input(profile: &Profile) {
 
 /// Verify that the driver does not insert from invalid memory if inserting a truncated value
 #[test_case(MSSQL; "Microsoft SQL Server")]
-#[test_case(MARIADB; "Maria DB")]
+// 'inconclusive' <= magic keyword used by test_case
+#[test_case(MARIADB; "Maria DB - expected fail inconclusive")] 
 #[test_case(SQLITE_3; "SQLite 3")]
 fn insert_truncated_value(profile: &Profile) {
     let conn = profile.connection().unwrap();
     let table_name = "InsertedTruncatedValue";
 
     // Prepare table content
-    setup_empty_table(&conn, profile.index_type, table_name, &["VARCHAR(13)"]).unwrap();
+    setup_empty_table(&conn, profile.index_type, table_name, &["VARCHAR(50)"]).unwrap();
 
     let memory = "Hello\0INVALID MEMORY\0";
     // Contains hello plus terminating zero.
@@ -2158,6 +2166,46 @@ fn insert_truncated_value(profile: &Profile) {
     }
 }
 
+#[test_case(MSSQL; "Microsoft SQL Server")]
+// 'inconclusive' <= magic keyword used by test_case
+#[test_case(MARIADB; "Maria DB expected fail inconclusive")]
+#[test_case(SQLITE_3; "SQLite 3")]
+fn insert_truncated_var_char_array(profile: &Profile) {
+    let conn = ENV
+        .connect_with_connection_string(profile.connection_string)
+        .unwrap();
+    let table_name = "InsertedTruncatedVarCharArray";
+
+    // Prepare table content
+    setup_empty_table(&conn, profile.index_type, table_name, &["VARCHAR(50)"]).unwrap();
+
+    let memory = "Hello, World!";
+    // Truncated value. Buffer can only hold 'Hello'
+    let parameter = VarCharArray::<5>::new(memory.as_bytes());
+    let result = conn.execute(
+        &format!("INSERT INTO {} (a) VALUES (?);", table_name),
+        &parameter,
+    );
+
+    match result {
+        Err(e) => {
+            // Failing is fine, especially with an error indicating truncation.
+            eprintln!("{}", e)
+        }
+        Ok(None) => {
+            // If this was successful we should make sure we did not insert 'INVALID MEMORY' into
+            // the database. The better database drivers do not do this, and this could be seen as
+            // wrong, but we are only interessted in unsafe behaviour.
+            let actual = table_to_string(&conn, table_name, &["a"]);
+            eprintln!("{}", actual);
+            // SQLite just emmits 'Hell' instead of 'Hello'. It's not beautiful, but it is not
+            // invalid memory access either.
+            assert!(matches!(actual.as_str(), "Hello" | "Hell"))
+        }
+        _ => panic!("Unexpected cursor"),
+    }
+}
+
 #[test_case(MSSQL; "Microsoft SQL Server")]
 #[test_case(MARIADB; "Maria DB")]
 #[test_case(SQLITE_3; "SQLite 3")]
